@@ -8,11 +8,12 @@ pub struct InternalContext {
 impl InternalContext {
     pub async fn new(
         google_application_credentials: String,
+        payment_processing_topic: String,
     ) -> Result<Self, cloud_pubsub::error::Error> {
         let pubsub_client = Arc::new(Client::new(google_application_credentials).await?);
 
         Ok(Self {
-            payment_processing_topic: Arc::new(pubsub_client.topic("".to_string())),
+            payment_processing_topic: Arc::new(pubsub_client.topic(payment_processing_topic)),
         })
     }
 }
