@@ -7,6 +7,7 @@ use crate::checkout::Checkout;
 use crate::context::Context;
 use crate::error::{new_application_error, Error};
 use crate::internal_context::InternalContext;
+use crate::money::Money;
 
 pub mod handlers;
 
@@ -15,6 +16,7 @@ pub struct Payment<CorrelationID, PrivateData, PublicData, ProcessArgs> {
     pub id: String,
     pub state: PaymentState<ProcessArgs>,
     pub checkout_id: String,
+    pub charge_amount: Money,
     pub data: PaymentData<CorrelationID, PrivateData, PublicData>,
 }
 
@@ -168,6 +170,7 @@ pub enum InternalPaymentState {
 async fn new<C: Context + Send>(
     ctx: &mut C,
     checkout_id: String,
+    charge_amount: Money,
     args: <C as PaymentProcessor>::InitiateArgs,
 ) -> Result<
     Payment<
@@ -182,6 +185,7 @@ async fn new<C: Context + Send>(
         id: Uuid::new_v4().to_string(),
         state: PaymentState::Idle,
         checkout_id,
+        charge_amount,
         data: PaymentData {
             correlation_id: None,
             private_data: None,
